# Please keep this package sync with FC
#
%global major 19.1
%global __requires_exclude	devel\\(libPollyPPCG|libPollyISL

%define libname %mklibname polly %{major}
%define devname %mklibname polly -d

%bcond_with cuda
%bcond_with gpgpu

%global toolchain clang
%global polly_version 19.1.7
#global rc_ver 4
%global polly_srcdir polly-%{polly_version}%{?rc_ver:-rc%{rc_ver}}.src

# Opt out of https://fedoraproject.org/wiki/Changes/fno-omit-frame-pointer
# https://bugzilla.redhat.com/show_bug.cgi?id=2158587
%undefine _include_frame_pointers


Name: polly
Version: %{polly_version}%{?rc_ver:~rc%{rc_ver}}
Release: %mkrel 1
Summary: LLVM Framework for High-Level Loop and Data-Locality Optimizations
Group: Development/Other
License: Apache-2.0 WITH LLVM-exception OR NCSA
URL: https://polly.llvm.org/
Source0: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{polly_version}%{?rc_ver:-rc%{rc_ver}}/%{polly_srcdir}.tar.xz
Source1: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{polly_version}%{?rc_ver:-rc%{rc_ver}}/%{polly_srcdir}.tar.xz.sig
Source2: release-keys.asc

Patch0: 0001-PATCH-polly-Portability-of-subproject-extension.patch

BuildRequires: cmake
BuildRequires: zlib-devel
BuildRequires: llvm-devel = %{version}
BuildRequires: llvm-cmake-utils = %{version}
BuildRequires: llvm-test = %{version}
BuildRequires: clang-devel = %{version}
BuildRequires: ninja-build
BuildRequires: python3-lit
BuildRequires: python3-sphinx
%if %{with cuda}
BuildRequires:	nvidia-cuda-toolkit
%endif

# For origin certification
BuildRequires:	gnupg2

%description
Polly is a high-level loop and data-locality optimizer and optimization
infrastructure for LLVM. It uses an abstract mathematical representation based
on integer polyhedron to analyze and optimize the memory access pattern of a
program.

%package -n %{libname}
Summary: LLVM Framework for High-Level Loop and Data-Locality Optimizations
Group: System/Libraries
Requires: %{name}-plugins%{?_isa} = %{version}-%{release}
Provides: %{name}%{?_isa} = %{version}-%{release}
Provides: %{name} = %{version}-%{release}
Obsoletes: %{name} < 19.1.3

%description -n %{libname}
Polly is a high-level loop and data-locality optimizer and optimization
infrastructure for LLVM. It uses an abstract mathematical representation based
on integer polyhedron to analyze and optimize the memory access pattern of a
program.

%package -n %{_lib}polly-plugins
Summary: Plugins and bindings for %{name}
Provides: %{name}-plugins%{?_isa} = %{version}-%{release}
Provides: %{name}-plugins%{?_isa} = %{version}-%{release}
Conflicts: %{name} < 19.1.3

%description -n %{_lib}polly-plugins
Plugins and bindings for %{name}.

%package -n %{devname}
Summary: Polly header files
Group: Development/Other
Requires: %{name}%{?_isa} = %{version}-%{release}
Provides: polly-devel%{?_isa} = %{version}-%{release}
Provides: polly-devel = %{version}-%{release}

%description -n %{devname}
Polly header files.

%package doc
Summary: Documentation for Polly
BuildArch: noarch
Requires: %{name} = %{version}-%{release}

%description doc
Documentation for the Polly optimizer.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -n %{polly_srcdir} -p2

%build

%cmake -GNinja \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
	-DCMAKE_PREFIX_PATH=%{_libdir}/cmake/llvm/ \
	-DLLVM_COMMON_CMAKE_UTILS=%{_datadir}/llvm/cmake \
\
	-DLLVM_ENABLE_SPHINX:BOOL=ON \
	-DSPHINX_WARNINGS_AS_ERRORS=OFF \
	-DSPHINX_EXECUTABLE=%{_bindir}/sphinx-build-3 \
\
%if %{with gpgpu}
	-DPOLLY_ENABLE_GPGPU_CODEGEN:BOOL=ON \
%endif
%if %{with cuda}
	-DCUDA_NVCC_EXECUTABLE:FILEPATH=%{_bindir}/nvcc
%endif
\
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64
%else
	-DLLVM_LIBDIR_SUFFIX=
%endif

%cmake_build
%cmake_build --target docs-polly-html


%install
%cmake_install

install -d %{buildroot}%{_pkgdocdir}/html
cp -r %{_vpath_builddir}/docs/html/* %{buildroot}%{_pkgdocdir}/html/

%check
# Test execution normally relies on RPATH, so set LD_LIBRARY_PATH instead.
export LD_LIBRARY_PATH=%{buildroot}/%{_libdir}
%cmake_build --target check-polly

%files -n %{libname}
%license LICENSE.TXT
%{_libdir}/libPolly.so.%{major}

%files -n %{_lib}polly-plugins
# these are libraries without .so versions, not devel
%{_libdir}/LLVMPolly.so
%if %{with gpgpu}
%ifarch %ix86 x86_64
%{_libdir}/libGPURuntime.so
%endif
%endif
%{_libdir}/libPollyISL.so

%files -n %{devname}
%{_libdir}/libPolly.so
%{_includedir}/polly
%{_libdir}/cmake/polly

%files doc
%doc %{_pkgdocdir}/html


%changelog
* Sat Apr 19 2025 wally <wally> 19.1.7-1.mga10
+ Revision: 2177244
- new version 19.1.7

* Sat Nov 09 2024 wally <wally> 19.1.3-1.mga10
+ Revision: 2113378
- new version 19.1.3
+ danf <danf>
- Update links to https:

* Fri Mar 22 2024 wally <wally> 17.0.6-1.mga10
+ Revision: 2051377
- new version 17.0.6 (sync with Fedora)

* Thu Dec 08 2022 ghibo <ghibo> 15.0.6-1.mga9
+ Revision: 1919346
- Update to release 15.0.6

* Tue Nov 15 2022 ghibo <ghibo> 15.0.4-1.mga9
+ Revision: 1907662
- Update to release 15.0.4
- Update to release 15.0.4

* Thu Sep 22 2022 tv <tv> 15.0.0-1.mga9
+ Revision: 1891425
+ rebuild (emptylog)

* Wed Jun 22 2022 ghibo <ghibo> 14.0.5-1.mga9
+ Revision: 1865401
- Update to release 14.0.5
- Update to release 14.0.3

* Wed Mar 30 2022 tv <tv> 14.0.0-1.mga9
+ Revision: 1835189
- Update to LLVM 14.0.0
- Update to LLVM 14.0.0

* Sun Mar 13 2022 ghibo <ghibo> 13.0.1-3.mga9
+ Revision: 1790833
- Update to release 13.0.1 final
- Avoid forcing optimization in polly script wrappers

* Thu Oct 21 2021 tv <tv> 13.0.0-2.mga9
+ Revision: 1752487
- Disable GPGPU_CODEGEN for now in order to fix build
- 13.0.0 Release

* Mon Jul 19 2021 tv <tv> 12.0.1-1.mga9
+ Revision: 1737066
- 12.0.1 Release

* Fri Apr 16 2021 tv <tv> 12.0.0-1.mga9
+ Revision: 1715997
- 12.0.0 final

* Fri Apr 09 2021 tv <tv> 12.0.0-0.7.rc5.mga9
+ Revision: 1714304
- 12.0.0 RC5

* Fri Apr 02 2021 tv <tv> 12.0.0-0.4.rc4.mga9
+ Revision: 1712641
- 12.0.0 RC4

* Sat Mar 13 2021 tv <tv> 12.0.0-0.4.rc3.mga9
+ Revision: 1701912
- drop SuSe patch that doesn't apply
- LLVM 12.0.0 rc3

* Thu Mar 04 2021 tv <tv> 12.0.0-0.2.rc2.mga9
+ Revision: 1698015
- 12.0.0-rc2 release

* Thu Jan 07 2021 tv <tv> 11.0.1-3.mga8
+ Revision: 1669447
- LLVM 11.0.1 final

* Tue Dec 22 2020 tv <tv> 11.0.1-2.rc2.mga8
+ Revision: 1662973
- llvm 11.0.1-rc2

* Fri Dec 04 2020 tv <tv> 11.0.1-1.rc1.mga8
+ Revision: 1652575
- llvm 11.0.1 RC1

* Fri Nov 27 2020 tv <tv> 11.0.0-1.mga8
+ Revision: 1649685
- libGPURuntime.so is there only on x86
- ignore testsuite results for now
- 11.0.0
- 11.0.0

* Thu Oct 08 2020 akien <akien> 10.0.1-1.mga8
+ Revision: 1632869
- Temporarily disable libGPURuntime on arm
- Version 10.0.1
+ ghibo <ghibo>
- Remove script to get git sources (obsolete)
- Add docs-polly-man to cmake target for building man pages.
- Add LLVMPolly.so, libGPURuntime.so, libPollyISL.so, libPollyPPCG.so to main package filelist.
- Reintroduce devel(libPollyPPCG|libPollyISL) requires_exception to allow polly-devel installation.
+ tv <tv>
- BR clang-devel
- gpgverify sources
- fix license
- better summary
- use new cmake macros
- no need for BR: llvm-static
- split devel pkg

* Fri Jun 12 2020 ghibo <ghibo> 10.0.0-6.mga8
+ Revision: 1592843
- merge ninja build targets

* Thu Jun 11 2020 ghibo <ghibo> 10.0.0-5.mga8
+ Revision: 1592619
- Fix docs

* Thu Jun 11 2020 ghibo <ghibo> 10.0.0-4.mga8
+ Revision: 1592591
- Add ninja-build to BuildRequires
- more fixing broken deps.
- cmake options cleanup.
- add cuda bcond.
- Add doc subpackage
- Add HTML docs
- Add man page
- Sync Patch0 from FC
- Add Patch1 from Suse for fixing pthread linking order.
- Fix broken deps about libPollyPPCG.
- Add llvm-test and python-sphinx to BuildRequires.
- Remove isl from BuildRequires and use newer bundled version.

* Tue Jun 09 2020 ghibo <ghibo> 10.0.0-3.mga8
+ Revision: 1591495
- Add OpenCL-devel and isl-devel to BuildRequires.

* Tue Jun 09 2020 ghibo <ghibo> 10.0.0-2.mga8
+ Revision: 1591451
- Bump release

* Tue Mar 24 2020 tv <tv> 10.0.0-1.mga8
+ Revision: 1559505
- 10.0.0 final

* Sun Mar 22 2020 tv <tv> 10.0.0-0.1.rc5.mga8
+ Revision: 1558889
- adjust filelist
- 10.0.0 rc5
- rebuild with llvm 10

* Sun Feb 16 2020 umeabot <umeabot> 9.0.0-3.mga8
+ Revision: 1533428
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sat Sep 21 2019 tv <tv> 9.0.0-2.mga8
+ Revision: 1444354
- 9.0.0 Release

* Tue Sep 17 2019 tv <tv> 9.0.0-1.mga8
+ Revision: 1443075
- 9.0.0rc3

* Sat Apr 13 2019 ghibo <ghibo> 8.0.0-1.mga7
+ Revision: 1389829
- Update to release 8.0.0.
- Build with llvm 8.0.0.

* Tue Mar 19 2019 ghibo <ghibo> 7.0.1-1.mga7
+ Revision: 1378899
- imported package polly


* Tue Mar 19 2019 ghibo <ghibo> - 7.0.1-1.mga7
- Initial release.
